==> jc-1.4.0.tar.gz: java/lang/Number.h <==
// public abstract class java.lang.Number

// class file dependencies
// @dep_class 9cd7252f79299280 java_lang_Number
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Number_H_
#define _JC_java_lang_Number_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_Number$sub_refs	_jc_java_lang_Number$sub_refs;
typedef struct _jc_java_lang_Number$sub_nonrefs	_jc_java_lang_Number$sub_nonrefs;
typedef struct _jc_java_lang_Number$refs	_jc_java_lang_Number$refs;
typedef struct _jc_java_lang_Number$nonrefs	_jc_java_lang_Number$nonrefs;
typedef struct _jc_java_lang_Number$object	_jc_java_lang_Number$object;

typedef struct _jc_java_lang_Number$fields_struct	_jc_java_lang_Number$fields_struct;
typedef const struct _jc_java_lang_Number$vmethods	_jc_java_lang_Number$vmethods;
typedef const struct _jc_java_lang_Number$vtable	_jc_java_lang_Number$vtable;
typedef const struct _jc_java_lang_Number$vtype	_jc_java_lang_Number$vtype;

// Class fields structure
struct _jc_java_lang_Number$fields_struct {
	_jc_char_array	*digits;
	jlong	serialVersionUID;
};
extern _jc_java_lang_Number$fields_struct _jc_java_lang_Number$class_fields;

// Constructors
extern void _jc_java_lang_Number$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Number$object *);

// Virtual methods
extern jbyte _jc_java_lang_Number$method$byteValue$47b3fce549cb5394(_jc_env *, struct _jc_java_lang_Number$object *);
extern jdouble _jc_java_lang_Number$method$doubleValue$05dbe7d7723f64d5(_jc_env *, struct _jc_java_lang_Number$object *);
extern jfloat _jc_java_lang_Number$method$floatValue$420f14e6005c2833(_jc_env *, struct _jc_java_lang_Number$object *);
extern jint _jc_java_lang_Number$method$intValue$337510d54bc426be(_jc_env *, struct _jc_java_lang_Number$object *);
extern jlong _jc_java_lang_Number$method$longValue$5ddb1017a7a6b2ba(_jc_env *, struct _jc_java_lang_Number$object *);
extern jshort _jc_java_lang_Number$method$shortValue$9543ee2ef3879446(_jc_env *, struct _jc_java_lang_Number$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_Number$method_info$byteValue$47b3fce549cb5394;
extern _jc_method _jc_java_lang_Number$method_info$doubleValue$05dbe7d7723f64d5;
extern _jc_method _jc_java_lang_Number$method_info$floatValue$420f14e6005c2833;
extern _jc_method _jc_java_lang_Number$method_info$intValue$337510d54bc426be;
extern _jc_method _jc_java_lang_Number$method_info$longValue$5ddb1017a7a6b2ba;
extern _jc_method _jc_java_lang_Number$method_info$shortValue$9543ee2ef3879446;

// Static methods
extern void _jc_java_lang_Number$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_lang_Number$vmethods {
	jbyte	(*byteValue$47b3fce549cb5394)(_jc_env *, struct _jc_java_lang_Number$object *);
	jdouble	(*doubleValue$05dbe7d7723f64d5)(_jc_env *, struct _jc_java_lang_Number$object *);
	jfloat	(*floatValue$420f14e6005c2833)(_jc_env *, struct _jc_java_lang_Number$object *);
	jint	(*intValue$337510d54bc426be)(_jc_env *, struct _jc_java_lang_Number$object *);
	jlong	(*longValue$5ddb1017a7a6b2ba)(_jc_env *, struct _jc_java_lang_Number$object *);
	jshort	(*shortValue$9543ee2ef3879446)(_jc_env *, struct _jc_java_lang_Number$object *);
};

// Vtable
struct _jc_java_lang_Number$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Number$vmethods	java_lang_Number;
};

// Vtype
struct _jc_java_lang_Number$vtype {
	_jc_type			type;
	_jc_java_lang_Number$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Number$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Number$refs {
    _jc_java_lang_Number$sub_refs	java_lang_Number;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Number$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Number$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Number$sub_nonrefs	java_lang_Number;
};

// Object instance structure
struct _jc_java_lang_Number$object {
	_jc_java_lang_Number$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Number$vtype	*vtype;
	_jc_java_lang_Number$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Number$vtype _jc_java_lang_Number$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Number, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Number$class_object;

#endif	/* _JC_java_lang_Number_H_ */

==> jc-1.4.6.tar.gz: java/lang/Number.h <==
// public abstract class java.lang.Number

// class file dependencies
// @dep_class 9cd7252f79299280 java_lang_Number
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Number_H_
#define _JC_java_lang_Number_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_Number$sub_refs	_jc_java_lang_Number$sub_refs;
typedef struct _jc_java_lang_Number$sub_nonrefs	_jc_java_lang_Number$sub_nonrefs;
typedef struct _jc_java_lang_Number$refs	_jc_java_lang_Number$refs;
typedef struct _jc_java_lang_Number$nonrefs	_jc_java_lang_Number$nonrefs;
typedef struct _jc_java_lang_Number$object	_jc_java_lang_Number$object;

typedef struct _jc_java_lang_Number$fields_struct	_jc_java_lang_Number$fields_struct;
typedef const struct _jc_java_lang_Number$vmethods	_jc_java_lang_Number$vmethods;
typedef const struct _jc_java_lang_Number$vtable	_jc_java_lang_Number$vtable;
typedef const struct _jc_java_lang_Number$vtype	_jc_java_lang_Number$vtype;

// Class fields structure
struct _jc_java_lang_Number$fields_struct {
	_jc_char_array	*digits;
	jlong	serialVersionUID;
};
extern _jc_java_lang_Number$fields_struct _jc_java_lang_Number$class_fields;

// Constructors
extern void _jc_java_lang_Number$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jbyte _jc_java_lang_Number$method$byteValue$47b3fce549cb5394(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_lang_Number$method$doubleValue$05dbe7d7723f64d5(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_lang_Number$method$floatValue$420f14e6005c2833(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_Number$method$intValue$337510d54bc426be(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_lang_Number$method$longValue$5ddb1017a7a6b2ba(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
extern jshort _jc_java_lang_Number$method$shortValue$9543ee2ef3879446(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_Number$method_info$byteValue$47b3fce549cb5394;
extern _jc_method _jc_java_lang_Number$method_info$doubleValue$05dbe7d7723f64d5;
extern _jc_method _jc_java_lang_Number$method_info$floatValue$420f14e6005c2833;
extern _jc_method _jc_java_lang_Number$method_info$intValue$337510d54bc426be;
extern _jc_method _jc_java_lang_Number$method_info$longValue$5ddb1017a7a6b2ba;
extern _jc_method _jc_java_lang_Number$method_info$shortValue$9543ee2ef3879446;

// Static methods
extern void _jc_java_lang_Number$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_Number$vmethods {
	jbyte	(*byteValue$47b3fce549cb5394)(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
	jdouble	(*doubleValue$05dbe7d7723f64d5)(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
	jfloat	(*floatValue$420f14e6005c2833)(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
	jint	(*intValue$337510d54bc426be)(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
	jlong	(*longValue$5ddb1017a7a6b2ba)(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
	jshort	(*shortValue$9543ee2ef3879446)(_jc_env *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_Number$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Number$vmethods	java_lang_Number;
};

// Vtype
struct _jc_java_lang_Number$vtype {
	_jc_type			type;
	_jc_java_lang_Number$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Number$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Number$refs {
    _jc_java_lang_Number$sub_refs	java_lang_Number;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Number$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Number$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Number$sub_nonrefs	java_lang_Number;
};

// Object instance structure
struct _jc_java_lang_Number$object {
	_jc_java_lang_Number$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Number$vtype	*vtype;
	_jc_java_lang_Number$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Number$vtype _jc_java_lang_Number$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Number, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Number$class_object;

#endif	/* _JC_java_lang_Number_H_ */
